@@ -21,6 +21,7 @@ Cyborg Intel FPGA driver implementation.
 import glob
 import os
 import re
+import socket
 
 from oslo_serialization import jsonutils
 
@@ -38,13 +39,12 @@ PCI_DEVICES_PATH_PATTERN = "/sys/bus/pci/devices/*"
 # TODO(shaohe) The KNOWN_FPGAS can be configurable.
 KNOWN_FPGAS = [("0x8086", "0x09c4")]
 
-INTEL_FPGA_DEV_PREFIX = "intel-fpga-dev"
 SYS_FPGA = "/sys/class/fpga"
 DEVICE = "device"
 PF = "physfn"
 VF = "virtfn*"
 BDF_PATTERN = re.compile(
-    "^[a-fA-F\d]{4}:[a-fA-F\d]{2}:[a-fA-F\d]{2}\.[a-fA-F\d]$")
+    r"^[a-fA-F\d]{4}:[a-fA-F\d]{2}:[a-fA-F\d]{2}\.[a-fA-F\d]$")
 
 DEVICE_FILE_MAP = {"vendor": "vendor",
                    "device": "product_id"}
@@ -199,11 +199,11 @@ def get_traits(device_name, product_id, vf=True):
         traits.append("CUSTOM_FPGA_INTEL")
         traits.append("CUSTOM_FPGA_INTEL_" + PRODUCT_MAP.get(product_id))
     for i in get_afu_ids(device_name):
-        l = "CUSTOM_FPGA_FUNCTION_ID_INTEL_" + i.upper()
-        traits.append(l)
+        trait = "CUSTOM_FPGA_FUNCTION_ID_INTEL_" + i.upper()
+        traits.append(trait)
     for i in get_region_ids(device_name):
-        l = "CUSTOM_FPGA_REGION_INTEL_" + i.upper()
-        traits.append(l)
+        trait = "CUSTOM_FPGA_REGION_INTEL_" + i.upper()
+        traits.append(trait)
     return {"traits": traits}
 
 
@@ -231,7 +231,7 @@ def fpga_tree():
         # name = os.path.basename(path)
         fpga = {"type": constants.DEVICE_FPGA,
                 "devices": bdf, "stub": True,
-                "name": "_".join((INTEL_FPGA_DEV_PREFIX, bdf))}
+                "name": "_".join((socket.gethostname(), bdf))}
         d_info = fpga_device(path)
         fpga.update(d_info)
         if names:
@@ -314,27 +314,24 @@ def _generate_attach_handle(fpga):
 
 def _generate_attribute_list(fpga):
     attr_list = []
-    index = 0
     for k, v in fpga.items():
         if k == "rc":
             driver_attr = driver_attribute.DriverAttribute()
             driver_attr.key, driver_attr.value = k, v
             attr_list.append(driver_attr)
         if k == "traits":
-            values = fpga.get(k, None)
-            for val in values:
+            values = fpga.get(k, [])
+            for index_pf, val in enumerate(values):
                 driver_attr = driver_attribute.DriverAttribute()
-                driver_attr.key = "trait" + str(index)
-                index = index + 1
+                driver_attr.key = "trait" + str(index_pf)
                 driver_attr.value = val
                 attr_list.append(driver_attr)
     if fpga.get("regions"):
         for vf in fpga["regions"]:
             for k, values in vf.items():
                 if k == "traits":
-                    for val in values:
+                    for index_vf, val in enumerate(values):
                         driver_attr = driver_attribute.DriverAttribute(
-                            key="trait" + str(index), value=val)
-                        index = index + 1
+                            key="trait" + str(index_vf + index_pf), value=val)
                         attr_list.append(driver_attr)
     return attr_list
